@@ -35,12 +35,10 @@
 #include <dom/dom_string.h>
 #include <dom/html_document.h>
 
-#include <kdebug.h>
 #include <kpluginfactory.h>
 #include <khtml_part.h>
 #include <khtmlview.h>
 #include <kiconloader.h>
-#include <kcomponentdata.h>
 #include <KLocalizedString>
 #include <QMenu>
 #include <ktoolbar.h>
@@ -60,7 +58,7 @@ Q_DECLARE_METATYPE(DOM::Element);
 /** Constructor of the plugin. */
 RelLinksPlugin::RelLinksPlugin(QObject *parent, const QVariantList &)
     : KParts::Plugin(parent),
-      m_part(0),
+      m_part(nullptr),
       m_viewVisible(false),
       m_linksFound(false)
 {
@@ -264,11 +262,11 @@ RelLinksPlugin::~RelLinksPlugin()
 
 bool RelLinksPlugin::eventFilter(QObject *watched, QEvent *event)
 {
-    if (m_part == 0) {
+    if (m_part == nullptr) {
         return false;
     }
 
-    if (watched == 0 || event == 0) {
+    if (watched == nullptr || event == nullptr) {
         return false;
     }
 
@@ -300,7 +298,7 @@ bool RelLinksPlugin::eventFilter(QObject *watched, QEvent *event)
 
 void RelLinksPlugin::delayedSetup()
 {
-    if (m_part == 0) {
+    if (m_part == nullptr) {
         return;
     }
 
@@ -357,7 +355,7 @@ void RelLinksPlugin::updateToolbar()
         QString rel = e.getAttribute("rel").string();
         rel = rel.simplified();
         if (rel.isEmpty()) {
-            // If the "rel" attribut is null then use the "rev" attribute...
+            // If the "rel" attribute is null then use the "rev" attribute...
             QString rev = e.getAttribute("rev").string();
             rev = rev.simplified();
             if (rev.isEmpty()) {
@@ -367,7 +365,7 @@ void RelLinksPlugin::updateToolbar()
             // Determine the "rel" equivalent of "rev" type
             rel =  transformRevToRel(rev);
         }
-        // Determin the name used internally
+        // Determine the name used internally
         QString lrel = getLinkType(rel.toLower());
         // relation to ignore
         if (lrel.isEmpty()) {
@@ -458,10 +456,10 @@ void RelLinksPlugin::guessRelations()
         return;
     }
 
-    // - The number of didgit may not be more of 3, or this is certenly an id.
+    // - The number of digits may not be more of 3, or this is certainly an id.
     // - We make sure that the number is followed by a dot, a &, or the end, we
     //   don't want to match stuff like that:   page.html?id=A14E12FD
-    // - We make also sure the number is not preceded dirrectly by others number
+    // - We make also sure the number is not preceded directly by others number
     QRegExp rx("^(.*[=/?&][^=/?&.\\-0-9]*)([\\d]{1,3})([.&][^/0-9]{0,15})?$");
 
     const QString zeros(QStringLiteral("0000"));
